//
//  ViewController.swift
//  demo
//
//  Created by Sinbad on 3/7/18.
//

import UIKit
import ReCaptcha
import WebKit

let ApiKey = "SET ME"
let BaseURL = URL(string: "SET ME")!

class ViewController: UIViewController {
  private final let _recaptcha = try? ReCaptcha(apiKey: ApiKey, baseURL: BaseURL)
  private final let _recaptchaV = UIView()
  private final let _btn = UIButton()
  private final let _lbl = UILabel()
  private final var _recaptchaReturnCount = 0

  override func viewDidLoad() {
    super.viewDidLoad()
    // Do any additional setup after loading the view, typically from a nib.
    
    __setupBtn()
    __setupReCaptcha()
    __setupLbl()
  }
  
  private final func __setupBtn() {
    view.addSubview(_btn)
    _btn.frame = CGRect(x: 0, y: 0, width: view.frame.width, height: 100)
    _btn.backgroundColor = UIColor.black.withAlphaComponent(0.7)
    _btn.setTitle("Click me", for: .normal)
    _btn.setTitleColor(.red, for: .normal)
    _btn.setTitleColor(.blue, for: .highlighted)
    _btn.addTarget(self, action: #selector(__callValidate), for: .touchUpInside)
  }
  
  private final func __setupLbl() {
    view.addSubview(_lbl)
    _lbl.frame = CGRect(x: 0, y: 100, width: view.frame.width, height: 50)
    _lbl.textColor = .black
    _lbl.adjustsFontSizeToFitWidth = true
    _lbl.backgroundColor = UIColor.green.withAlphaComponent(0.2)
  }
  
  private final func __setupReCaptcha() {
    view.addSubview(_recaptchaV)
    _recaptchaV.frame = CGRect(x: 0, y: 100, width: view.frame.width, height: view.frame.height - 100)
    _recaptchaV.backgroundColor = UIColor.gray.withAlphaComponent(0.3)
    
    _recaptcha?.configureWebView { [weak self] (webview: WKWebView) in
      debugPrint("--- recaptcha Config")
      guard let sSelf = self else { return }
  
      sSelf._recaptchaV.addSubview(webview)
      webview.frame = CGRect(x: 0, y: 0, width: sSelf._recaptchaV.frame.width, height: sSelf._recaptchaV.frame.height)
    }
  }
  
  @objc func __callValidate() {
    guard let r = _recaptcha else {
      debugPrint("--NO RECAPTCHA")
      return
    }
    
    debugPrint(" ---  calling validate")
    let start = Date()
    r.validate(on: view) { [weak self] (result: ReCaptchaWebViewManager.Response) in
      self?._recaptchaReturnCount += 1
      var countTxt = "--"
      if let count = self?._recaptchaReturnCount {
        countTxt = "\(count)"
      }
      let txt = "Validate Completed \(countTxt) times.  Started \(Date().timeIntervalSince(start)) seconds ago"
      debugPrint(txt)
      self?._lbl.text = txt
      
      switch result {
      case .success(let captcha):
        debugPrint("Captcha: \(captcha)")
      case .failure(let error):
        debugPrint(error.description)
        switch error {
        case .apiKeyNotFound: preconditionFailure("Must set ReCaptcha API Key")
        case .baseURLNotFound: preconditionFailure("Must set ReCaptcha baseURL")
        case .htmlLoadError: assertionFailure(); break
        case .wrongMessageFormat: assertionFailure(); break
        case .unexpected: break
        }
      }
    }
  }
}
